@@ -2,23 +2,23 @@ import gc
 from time import time
 
 import pandas as pd
-from memory_profiler import memory_usage
+
+# from memory_profiler import memory_usage
 
 
 def profile(nrange, func, *args):
-    res = pd.DataFrame(index=nrange, columns=["Time", "Memory"])
+    res = pd.DataFrame(index=nrange, columns=["Time", "Memory", "Objective"])
 
     for N in res.index:
         start = time()
 
-        func(N, *args)
+        objective = func(N, *args)
 
         end = time()
         duration = end - start
 
-        memory = memory_usage((func, (N, *args)))
-
-        res.loc[N] = duration, max(memory)
+        res.loc[N, "Time"] = duration
+        res.loc[N, "Objective"] = objective
 
         gc.collect()
 
