@@ -1,15 +1,12 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 Created on Fri Nov 19 17:40:33 2021.
 
 @author: fabian
 """
 
-
-import pandas as pd
 from common import profile
-from numpy import arange, cos, sin
+from numpy import arange
 
 from linopy import Model
 
