@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+
 
 import pytest
 
@@ -7,11 +7,11 @@ from linopy.config import OptionSettings
 
 
 @pytest.fixture
-def options():
+def options() -> OptionSettings:
     return OptionSettings(a=1, b=2, c=3)
 
 
-def test_set_value(options):
+def test_set_value(options: OptionSettings) -> None:
     options.set_value(a=10)
     assert options._current_values == {"a": 10, "b": 2, "c": 3}
 
@@ -19,14 +19,14 @@ def test_set_value(options):
         options.set_value(d=20)
 
 
-def test_get_value(options):
+def test_get_value(options: OptionSettings) -> None:
     assert options.get_value("a") == 1
 
     with pytest.raises(KeyError, match="d is not a valid setting."):
         options.get_value("d")
 
 
-def test_call(options):
+def test_call(options: OptionSettings) -> None:
     options(a=10)
     assert options._current_values == {"a": 10, "b": 2, "c": 3}
 
@@ -34,14 +34,14 @@ def test_call(options):
         options(d=20)
 
 
-def test_getitem(options):
+def test_getitem(options: OptionSettings) -> None:
     assert options["a"] == 1
 
     with pytest.raises(KeyError, match="d is not a valid setting."):
         options["d"]
 
 
-def test_setitem(options):
+def test_setitem(options: OptionSettings) -> None:
     options["a"] = 10
     assert options._current_values == {"a": 10, "b": 2, "c": 3}
 
@@ -49,18 +49,18 @@ def test_setitem(options):
         options["d"] = 20
 
 
-def test_repr(options):
+def test_repr(options: OptionSettings) -> None:
     repr(options)
 
 
-def test_with_statement(options):
+def test_with_statement(options: OptionSettings) -> None:
     with options as o:
         o.set_value(a=3)
         assert o.get_value("a") == 3
     assert options.get_value("a") == 1
 
 
-def test_reset(options):
+def test_reset(options: OptionSettings) -> None:
     options(a=10)
     options.reset()
     assert options._current_values == {"a": 1, "b": 2, "c": 3}
